package info.bukova.isspst.services.approved;

import info.bukova.isspst.data.AddressEmb;
import info.bukova.isspst.data.JoinedItem;
import info.bukova.isspst.data.Order;
import info.bukova.isspst.data.OrderItem;
import info.bukova.isspst.services.AbstractOwnedService;
import info.bukova.isspst.services.LazyLoader;
import info.bukova.isspst.services.settings.GlobalSettingsService;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

import org.hibernate.Hibernate;
import org.hibernate.Query;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.annotation.Transactional;

public class OrderServiceImpl extends AbstractOwnedService<Order> implements
		OrderService {

	@Autowired
	private GlobalSettingsService globalSettings;
	
	@Override
	@PreAuthorize("hasPermission(this, 'PERM_ADD')")
	public Order createOrder(List<JoinedItem> items) {
		Order order = new Order();
		
		order.setAddress(new AddressEmb(globalSettings.getSettings().getMainAddress()));
		order.setDeliveryAddress(new AddressEmb(globalSettings.getSettings().getMainAddress()));
		order.setOrderDate(new Date());
		
		BigDecimal total = BigDecimal.ZERO;
		
		for (JoinedItem item : items) {
			total = total.add(item.getTotal());
			order.addItem(new OrderItem(item.getItem()));
		}
		
		order.setTotal(total);
		
		return order;
	}
	
	@Override
	@Transactional
	@PreAuthorize("hasPermission(this, 'PERM_ADD')")
	public void add(Order order) {
		order.setNumser(getNumberSerie());
		super.add(order);
	}

	@SuppressWarnings("unchecked")
	@Override
	@Transactional
	@PreAuthorize("hasPermission(this, 'PERM_READ')")
	public List<Order> getAll()
	{
		Query q = dao.getQuery("select o from Order o join fetch o.ownedBy");
		return q.list();
	}

	@LazyLoader("form")
	@Transactional
	public void lazyLoadOwnedBy(Order order)
	{
		if (order == null)
		{
			return;
		}

		Order o = dao.getById(order.getId());
		Hibernate.initialize(o.getOwnedBy());
		order.setOwnedBy(o.getOwnedBy());
	}

	@LazyLoader({ "form", "grid" })
	@Transactional
	public void lazyLoadItems(Order order)
	{
		if (order == null)
		{
			return;
		}

		Order o = dao.getById(order.getId());
		Hibernate.initialize(o.getItems());
		order.setItems(o.getItems());
	}
}
