package info.bukova.isspst.ui.main.orders.created;

import info.bukova.isspst.data.Address;
import info.bukova.isspst.data.AddressEmb;
import info.bukova.isspst.data.Order;
import info.bukova.isspst.data.OrderItem;
import info.bukova.isspst.services.addressbook.AdbService;
import info.bukova.isspst.services.settings.GlobalSettingsService;
import info.bukova.isspst.ui.FormViewModel;
import info.bukova.isspst.validators.OrderFormValidator;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.zkoss.bind.annotation.Command;
import org.zkoss.bind.annotation.Init;
import org.zkoss.bind.annotation.NotifyChange;
import org.zkoss.zk.ui.select.annotation.WireVariable;

public class OrderForm extends FormViewModel<Order>
{
	@SuppressWarnings("unused")
	private final static Logger log = LoggerFactory.getLogger(OrderForm.class.getName());

	@WireVariable
	protected AdbService adbService;

	@WireVariable
	protected GlobalSettingsService settingsService;

	protected OrderFormValidator orderFormValidator;

	protected OrderItem selectedItem;

	protected Address selectedSuppAddrItem;

	protected Address selectedDeliveryAddrItem;

	protected String suppCompany;

	protected String deliveryCompany;

	@Init(superclass = true)
	public void initOrderForm()
	{
		this.orderFormValidator = new OrderFormValidator();

		if (this.getDataBean().getSuplier() == null)
		{
			this.getDataBean().setSuplier(new AddressEmb());
		}

		this.selectedSuppAddrItem = this.getDataBean().getSuplier().getAddress();
		this.suppCompany = this.selectedSuppAddrItem.getCompany();

		if (this.getDataBean().getDeliveryAddress() == null)
		{
			this.getDataBean().setDeliveryAddress(new AddressEmb());
		}

		this.selectedDeliveryAddrItem = this.getDataBean().getDeliveryAddress().getAddress();
		this.deliveryCompany = this.selectedDeliveryAddrItem.getCompany();

		if (this.getDataBean().getAddress() == null)
		{
			this.getDataBean().setAddress(new AddressEmb());
		}
	}

	public OrderFormValidator getOrderFormValidator()
	{
		return orderFormValidator;
	}

	public void setOrderFormValidator(OrderFormValidator orderFormValidator)
	{
		this.orderFormValidator = orderFormValidator;
	}

	public List<Address> getSuppAddresses()
	{
		return adbService.getAll();
	}

	public List<Address> getDeliveryAddresses()
	{
		return settingsService.getSettings().getAllShippingAddrs();
	}

	public Address getInvoiceAddress()
	{
		return settingsService.getSettings().getMainAddress();
	}

	public OrderItem getSelectedItem()
	{
		return this.selectedItem;
	}

	public void setSelectedItem(OrderItem selectedItem)
	{
		this.selectedItem = selectedItem;
	}

	public Address getSelectedSuppAddrItem()
	{
		return selectedSuppAddrItem;
	}

	public void setSelectedSuppAddrItem(Address selectedSuppAddrItem)
	{
		this.selectedSuppAddrItem = selectedSuppAddrItem;
	}

	public Address getSelectedDeliveryAddrItem()
	{
		return selectedDeliveryAddrItem;
	}

	public void setSelectedDeliveryAddrItem(Address selectedDeliveryAddrItem)
	{
		this.selectedDeliveryAddrItem = selectedDeliveryAddrItem;
	}

	public String getSuppCompany()
	{
		return suppCompany;
	}

	public void setSuppCompany(String suppCompany)
	{
		this.suppCompany = suppCompany;
	}

	public String getDeliveryCompany()
	{
		return deliveryCompany;
	}

	public void setDeliveryCompany(String deliveryCompany)
	{
		this.deliveryCompany = deliveryCompany;
	}

	@Command
	@NotifyChange("dataBean")
	public void doFillSuppAddress()
	{
		AddressEmb addr;

		if (this.selectedSuppAddrItem == null)
		{
			addr = this.getDataBean().getSuplier();
			addr.setId(0);
			addr.setCompany(this.suppCompany);
		}
		else
		{
			// Naplnit pole podle vybrané adresy z comba
			addr = new AddressEmb(this.selectedSuppAddrItem);
		}

		this.getDataBean().setSuplier(addr);
	}

	@Command
	@NotifyChange("dataBean")
	public void doFillDeliveryAddress()
	{
		AddressEmb addr;

		if (this.selectedDeliveryAddrItem == null)
		{
			addr = this.getDataBean().getDeliveryAddress();
			addr.setId(0);
			addr.setCompany(this.deliveryCompany);
		}
		else
		{
			// Naplnit pole podle vybrané adresy z comba
			addr = new AddressEmb(this.selectedDeliveryAddrItem);
		}

		this.getDataBean().setDeliveryAddress(addr);
	}
}
